@@ -72,6 +72,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
             self._domain = agent.iloc[0]['domain']
             self._language = agent.iloc[0]['language']
             self._agent_name = agent.iloc[0]['name']
+            self.slug = agent.iloc[0]['slug']
 
         except Exception as ex:
             raise NameError('Agent slug/name/id not exsist or not insert')
@@ -216,14 +217,14 @@ class Agent(Insight, Channel, Catalog, Dataset):
         response.raise_for_status()
         r = response.json()
 
-    def _load_dataset(self, dataset):
+    def _load_dataset(self, dataset_id):
 
         s = requests.Session()
         s.keep_alive = False
         retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
         s.mount('https://', HTTPAdapter(max_retries=retries))
 
-        authentication_url = self._base_url_askdata + '/smartdataset/datasets/' + dataset["id"] + '/grid/data'
+        authentication_url = self._base_url_askdata + '/smartdataset/datasets/' + dataset_id + '/grid/data'
         logging.info("AUTH URL {}".format(authentication_url))
 
         headers = {"Authorization": "Bearer" + " " + self._token}
@@ -241,12 +242,32 @@ class Agent(Insight, Channel, Catalog, Dataset):
         '''
 
         dataset = self.get_dataset_by_slug(self._agentId, dataset_slug)
+
         if(dataset == None):
-            logging.error("Please insert a correct dataset slug")
-            return
+
+            s = requests.Session()
+            s.keep_alive = False
+            retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+            s.mount('https://', HTTPAdapter(max_retries=retries))
+
+            url = self._base_url_askdata + '/agents/agentslug/'+self.slug+'/datasetslug/'+dataset_slug
+            logging.info("URL {}".format(url))
+
+            headers = {"Authorization": "Bearer" + " " + self._token}
+            response = s.get(url=url, headers=headers)
+            response.raise_for_status()
+            r = response.json()
+
+            try:
+                 dataset_id = r["datasetId"]
+            except:
+                logging.error("Please insert a correct dataset slug")
+                return
+        else:
+            dataset_id = dataset["id"]
 
         if(aliases==[]):
-            return self._load_dataset(dataset)
+            return self._load_dataset(dataset_id)
 
         dataset_id = dataset["id"]
         url_get = self.smart_insight_url + "/composed_queries?datasetId=" + dataset_id
@@ -487,7 +508,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
         else:
             raise Exception('takes 2 positional arguments "slug, datset_id" but 0 were given')
 
-    def create_datacard(self, channel: str, title: str, search: str = "", slug: str = None, replace: bool = False):
+    def create_datacard(self, channel_name: str, title: str, search: str = "", slug: str = None, replace: bool = False):
 
         if (replace == True and slug != None):
             try:
@@ -499,11 +520,11 @@ class Agent(Insight, Channel, Catalog, Dataset):
             print("Please specify a datacard slug to replace!")
             return
 
-        channel = self.get_channel(self._agentId, channel)
+        channel = self.get_channel(self._agentId, channel_name)
         if channel != None:
             channel_id = channel["id"]
         else:
-            channel_id = self.create_channel(channel)
+            channel_id = self.create_channel(channel_name)
 
         body = {
             "agentId": self._agentId,
