@@ -114,7 +114,38 @@ class Insight_Definition:
         self.components = r.json()["components"]
 
 
-    def add_chart(self, type="", query="", params=[]):
+    def get_result_set(self, query_id):
+
+        url = self.smart_insight_url+"/definitions/"+self.definition_id+"/queries/resultset/"+query_id
+
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+        headers = {
+            "Content-Type": "application/json",
+            "Authorization": "Bearer" + " " + self._token
+        }
+        r = s.get(url=url, headers=headers)
+        r.raise_for_status()
+        response = r.json()
+        columns = []
+        for column in response["schema"]:
+            columns.append(column["name"])
+
+        result_set = {}
+
+        for i in range(len(columns)):
+            row = []
+            for temp_row in response["data"]:
+                row.append(temp_row["cells"][i]["rawValue"])
+            result_set[columns[i]] = row
+
+        return pd.DataFrame(data=result_set)
+
+
+    def add_chart(self, type="", query="", params=[], title = "Chart"):
         position = (len(self.components))
         body = {"type": "chart", "position": position}
 
@@ -135,14 +166,14 @@ class Insight_Definition:
         self.components = r.json()["components"]
 
         if (type != "" and query != "" and params!=[]):
-            self.edit_chart(self.components[position]["id"], type, query, params)
+            self.edit_chart(self.components[position]["id"], type, query, params, title)
         else:
             logging.info("One or more arguments between type, query and params are missing to update the chart")
 
         return self.components[position]["id"]
 
 
-    def edit_chart(self, chart_id, chart_type:str, query, params):
+    def edit_chart(self, chart_id, chart_type:str, query, params, title = "Chart"):
 
         url = self.smart_insight_url + "/definitions/" + self.definition_id + "/charts/" + chart_id
 
@@ -153,7 +184,7 @@ class Insight_Definition:
             "customName": False,
             "dependsOn": [],
             "id": chart_id,
-            "name": "Fusionfood",
+            "name": title,
             "params": upper_params,
             "queryComponent": False,
             "queryId": query,
